audioflinger: Add flag OFFLOAD to track flags

If the playback thread is Offload, add
AUDIO_OUTPUT_FLAG_COMPRESS_OFFLOAD to the track's flags.
This helps the track to be consistent with the others
running in offload thread.

Bug: 341639197
Test:
- run CtsMediaAudioTestCases pass.
- Functional test - use exoplayer application to play multichannel
  AAC content then switches to play Dolby format content, both content
  playback are normal.

Change-Id: I9d9e41492824c9c43065dd723f9cb78d1a476523
diff --git a/services/audioflinger/Threads.cpp b/services/audioflinger/Threads.cpp
index 1d7c356..096f399 100644
--- a/services/audioflinger/Threads.cpp
+++ b/services/audioflinger/Threads.cpp
@@ -2690,14 +2690,17 @@
             }
         }
 
         // Set DIRECT flag if current thread is DirectOutputThread. This can
         // happen when the playback is rerouted to direct output thread by
         // dynamic audio policy.
         // Do NOT report the flag changes back to client, since the client
         // doesn't explicitly request a direct flag.
         audio_output_flags_t trackFlags = *flags;
         if (mType == DIRECT) {
             trackFlags = static_cast<audio_output_flags_t>(trackFlags | AUDIO_OUTPUT_FLAG_DIRECT);
+        } else if (mType == OFFLOAD) {
+            trackFlags = static_cast<audio_output_flags_t>(trackFlags |
+                                   AUDIO_OUTPUT_FLAG_COMPRESS_OFFLOAD | AUDIO_OUTPUT_FLAG_DIRECT);
         }
         *afTrackFlags = trackFlags;
@@ -2690,14 +2690,17 @@
         }
 
-        // Set DIRECT flag if current thread is DirectOutputThread. This can
-        // happen when the playback is rerouted to direct output thread by
+        // Set DIRECT/OFFLOAD flag if current thread is DirectOutputThread/OffloadThread.
+        // This can happen when the playback is rerouted to direct output/offload thread by
         // dynamic audio policy.
         // Do NOT report the flag changes back to client, since the client
@@ -2690,14 +2690,17 @@
         // dynamic audio policy.
         // Do NOT report the flag changes back to client, since the client
-        // doesn't explicitly request a direct flag.
+        // doesn't explicitly request a direct/offload flag.
         audio_output_flags_t trackFlags = *flags;
         if (mType == DIRECT) {